package com.caimei365.user.controller;

import com.caimei365.user.model.ResponseJson;
import com.caimei365.user.service.BaseService;
import io.swagger.annotations.*;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.*;

import java.util.Map;

/**
 * 用户公共API
 *
 * @author : Charles
 * @date : 2021/3/4
 */
@Api(tags="用户公共API")
@RestController
@RequiredArgsConstructor
@RequestMapping("/user")
public class BaseApi {

    private final BaseService baseService;
    @Value(value = "${swagger.enabled}")
    private Boolean swaggerEnabled;

    @GetMapping({"", "/"})
    public String welcome(){
        if (swaggerEnabled){
            return "欢迎使用！<br><a href='http://47.119.112.46:18011/doc.html'>doc接口文档入口(beta)</a><br><a href='http://47.119.112.46:18011/swagger-ui/index.html'>swagger接口文档入口(beta)</a>";
        }
        return "欢迎使用！";
    }

    /**
     * 获取图片验证码
     *
     * spi旧接口：/user/getImgVerifyCode
     *
     * @param platformType 0:www，1:crm/h5，2:小程序
     */
    @ApiOperation("获取图片验证码")
    @ApiImplicitParam(required = true, name = "platformType", value = "0:www，1:crm/h5，2:小程序")
    @GetMapping("/captcha")
    public ResponseJson<Map<String, Object>> getCaptchaImage(Integer platformType) {
        return baseService.getCaptchaImage(platformType);
    }

    /**
     * 获取短信验证码
     *
     * spi旧接口：/user/activateCodeByReg
     *
     * @param mobile           手机号
     * @param activateCodeType 1:找回密码,2:手机号注册机构,3:供应商注册
     * @param platformType     0:www，1:crm/h5，2:小程序
     * @param isCheckCaptcha   是否检查图片验证码，0:检查，1:不检查
     * @param imgCode          图片验证码
     * @param token            图片验证码token
     */
    @ApiOperation("获取短信验证码")
    @ApiImplicitParams({
        @ApiImplicitParam(required = true, name = "mobile", value = "手机号"),
        @ApiImplicitParam(required = true, name = "activateCodeType", value = "1:找回密码,2:手机号注册机构,3:供应商注册"),
        @ApiImplicitParam(required = false, name = "platformType", value = "0:www，1:crm/h5，2:小程序"),
        @ApiImplicitParam(required = false, name = "isCheckCaptcha", value = "是否检查图片验证码，0:检查，1:不检查"),
        @ApiImplicitParam(required = false, name = "imgCode", value = "图片验证码"),
        @ApiImplicitParam(required = false, name = "token", value = "图片token")

    })
    @GetMapping("/sms/code")
    public ResponseJson getSmsCode(String mobile, Integer activateCodeType, Integer platformType, Integer isCheckCaptcha, String imgCode, String token) {
        return baseService.getSmsCode(mobile, activateCodeType, platformType, isCheckCaptcha, imgCode, token);
    }

    /**
     * 绑定账号,发送短信验证
     *
     * spi旧接口：/user/note
     *
     * @param mobile           运营人员手机号
     * @param bindMobile       机构手机号
     * @param userId           机构Id
     * @param platformType     0:www，1:crm/h5，2:小程序
     * @param isCheckCaptcha   是否检查图片验证码，0:检查，1:不检查
     * @param imgCode          图片验证码
     * @param token            图片验证码token
     */
    @ApiOperation("绑定账号,发送短信验证")
    @ApiImplicitParams({
        @ApiImplicitParam(required = true, name = "mobile", value = "运营人员手机号"),
        @ApiImplicitParam(required = false, name = "bindMobile", value = "机构手机号"),
        @ApiImplicitParam(required = false, name = "userId", value = "机构Id"),
        @ApiImplicitParam(required = false, name = "platformType", value = "0:www，1:crm/h5，2:小程序"),
        @ApiImplicitParam(required = false, name = "isCheckCaptcha", value = "是否检查图片验证码，0:检查，1:不检查"),
        @ApiImplicitParam(required = false, name = "imgCode", value = "图片验证码"),
        @ApiImplicitParam(required = false, name = "token", value = "图片token")
    })
    @GetMapping("/sms/bind")
    public ResponseJson getBindSmsCode(String mobile, String bindMobile, Integer userId, Integer platformType, Integer isCheckCaptcha, String imgCode, String token) {
        return baseService.getBindSmsCode(mobile, bindMobile, userId, platformType, isCheckCaptcha, imgCode, token);
    }
}
