package com.caimei365.user.service;

import com.caimei365.user.model.ResponseJson;
import com.caimei365.user.model.dto.ClubUpdateDto;
import com.caimei365.user.model.po.ClubPo;

import java.util.Map;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/3/15
 */
public interface ClubService {
    /**
     * 根据用户Id查询机构资料
     * @param userId 用户Id
     *
     * @return Map(userPo,clubPo)
     */
    ResponseJson<Map<String, Object>> getClubUserInfo(Integer userId);

    /**
     * 修改机构资料
     *
     * @param club ClubUpgradeDto:{
     *                      clubId                 机构ID
     *                      userId                 用户ID
     *                      name                   机构名称
     *                      shortName                  机构简称(shortName)
     *                      contractEmail          邮箱（contractEmail1）
     *                      contractPhone          固定电话
     *                      linkMan                联系人（linkMan1）
     *                      provinceId             省Id
     *                      cityId                 市Id
     *                      townId                 县区Id
     *                      address                地址
     *                      shopPhoto              门头照(headpic)
     *                      businessLicense        营业执照（businessLicenseImage）
     *                      socialCreditCode       统一社会信用代码（socialCreditCode）
     *                      firstClubType          一级分类：医美=1和生美=2
     *                      secondClubType         医美的二级分类：诊所=1、门诊=2、医院=3。  生美没有二级分类
     *                      department             医美分类下的门诊和医院则需要填写科室
     *                      medicalPracticeLicense 医美分类必须上传医疗执业许可证（medicalPracticeLicenseImg）
     *                      mainProduct            主打项目（mainpro）
     *                      fax                    传真
     *                      profile                公司简介
     *                  }
     * @return ClubUpdateDto
     */
    ResponseJson<ClubUpdateDto> updateClubUserInfo(ClubUpdateDto club);

    /**
     * 机构个人中心
     *
     * @param userId 用户Id
     * @return Map(userPo,clubPo)
     */
    ResponseJson<Map<String, Object>> getClubHomeData(Integer userId);
}
